==> spectus_tus_uploader-0.0.7.tar.gz: ios/Classes/SwiftSpectusTusUploaderPlugin.swift <==
import Flutter
import UIKit

public class SwiftSpectusTusUploaderPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "spectus_tus_uploader", binaryMessenger: registrar.messenger())
        let instance = SwiftSpectusTusUploaderPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        } else if (call.method == "pickVideoFrom") {
            APImagePicker.sharedInstance.pickVideoFrom(requiredEditting: false, completion: { mediaPath in
                result(mediaPath)
            })
        } else if (call.method == "uploadFileWithTUS") {
            guard let args = call.arguments else {
                return
            }
            if let myArgs = args as? [String: Any], let uploadURLPath = myArgs["uploadURLPath"] as? String, let filePath = myArgs["filePath"] as? String, let fileTypeVal = myArgs["fileType"] as? String,let authEmailVal = myArgs["authEmail"] as? String,let authKeyVal = myArgs["authKey"] as? String,let authTokenVal = myArgs["authToken"] as? String {
                
                FileUploaderHelper.shared.initialiseUploaderWith(uploadURLPath)
                let localPathURL = URL.init(fileURLWithPath: filePath)
                FileUploaderHelper.shared.uploadFileWith(fileURL: localPathURL, fileType: fileTypeVal, authEmail: authEmailVal, authKey: authKeyVal, authToken: authTokenVal, progressHandler: { (uploaded, total) in
                    print("Uploaded: \(uploaded) MB\nTotal: \(total) MB")
                }, successOrFailureHandler: { (error, uploadedFilePath) in
                    if let errorMessage = error { //Fail
                        print("Error in upload!!!!\n\(errorMessage)")
                        result("")
                    } else { //Success
                        print("Uploaded Successfully." + "\nUploaded File Path: \(uploadedFilePath)")
                        result(uploadedFilePath)
                    }
                })
                
            }
        }
    }
}

==> spectus_tus_uploader-0.0.9.tar.gz: ios/Classes/SwiftSpectusTusUploaderPlugin.swift <==
import Flutter
import UIKit

public class SwiftSpectusTusUploaderPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "spectus_tus_uploader", binaryMessenger: registrar.messenger())
        let instance = SwiftSpectusTusUploaderPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        } else if (call.method == "pickVideoFrom") {
            APImagePicker.sharedInstance?.pickVideoFrom(requiredEditting: false){ mediaPath in
                result(mediaPath)
            }
        } else if (call.method == "uploadFileWithTUS") {
            guard let args = call.arguments else {
                return
            }
            if let myArgs = args as? [String: Any], let uploadURLPath = myArgs["uploadURLPath"] as? String, let filePath = myArgs["filePath"] as? String, let fileTypeVal = myArgs["fileType"] as? String,let authEmailVal = myArgs["authEmail"] as? String,let authKeyVal = myArgs["authKey"] as? String,let authTokenVal = myArgs["authToken"] as? String {
                
                FileUploaderHelper.shared.initialiseUploaderWith(uploadURLPath)
                let localPathURL = URL.init(fileURLWithPath: filePath)
                FileUploaderHelper.shared.uploadFileWith(fileURL: localPathURL, fileType: fileTypeVal, authEmail: authEmailVal, authKey: authKeyVal, authToken: authTokenVal, progressHandler: { (uploaded, total) in
                    print("Uploaded: \(uploaded) MB\nTotal: \(total) MB")
                }, successOrFailureHandler: { (error, uploadedFilePath) in
                    if let errorMessage = error { //Fail
                        print("Error in upload!!!!\n\(errorMessage)")
                        result("")
                    } else { //Success
                        print("Uploaded Successfully." + "\nUploaded File Path: \(uploadedFilePath)")
                        result(uploadedFilePath)
                    }
                })
                
            }
        }
    }
}
